@@ -360,20 +360,22 @@ class Graph():
         raise ValueError(
             f"Specified name {name} does not define a path in your GFA file.")
 
-    def compute_networkx(self) -> MultiDiGraph:
+    def compute_networkx(self, node_prefix: str | None = None) -> MultiDiGraph:
         """Computes the networkx representation of the GFA.
 
         Returns:
             MultiDiGraph: a networkx graph featuring the maximum of information
         """
+        node_prefix = f"{node_prefix}_" if node_prefix is not None else ""
         for node in self.segments:
             self.graph.add_node(
-                str(node.datas["name"]),
+                f"{node_prefix}{node.datas['name']}",
                 title=f"Len. {str(node.datas['length'])}",
                 color='darkslateblue',
                 size=log10(node.datas["length"])
             )
-        palette: list = get_palette(len(path_list := self.get_path_list()))
+        palette: list = get_palette(
+            len(path_list := self.get_path_list()), as_hex=True)
         if len(path_list) > 0:
             visited_paths: int = 0
             for visited_path in path_list:
@@ -381,19 +383,21 @@ class Graph():
                     left_node, left_orient = visited_path.datas["path"][i]
                     right_node, right_orient = visited_path.datas["path"][i+1]
                     self.graph.add_edge(
-                        str(left_node),
-                        str(right_node),
+                        f"{node_prefix}{left_node}",
+                        f"{node_prefix}{right_node}",
                         title=str(visited_path.datas["name"]),
                         color=palette[visited_paths],
-                        label=f"{left_orient.value}/{right_orient.value}"
+                        label=f"{left_orient.value}/{right_orient.value}",
+                        weight=3
                     )
                 visited_paths += 1
         else:
             for edge in self.lines:
                 self.graph.add_edge(
-                    str(edge.datas["start"]),
-                    str(edge.datas["end"]),
+                    f"{node_prefix}{edge.datas['start']}",
+                    f"{node_prefix}{edge.datas['end']}",
                     color='darkred',
-                    label=edge.datas["orientation"]
+                    label=edge.datas["orientation"],
+                    weight=3
                 )
         return self.graph
